import os
import slack


class Daniel:
    def __init__(self, emoticon=' :dollar: ', token=None, channel='automatic-reporting'):
        """Create the Daniel."""
        self.ender = emoticon
        self.starter = emoticon
        self.channel = channel
        if not token:
            token = os.environ["slack_token"]
        self.client = slack.WebClient(token=token)

    def say(self, msg, channel=None, enders=True):
        if channel is None:
            channel=self.channel
        if enders:
            self.client.chat_postMessage(
                    channel=channel,
                    text=self.starter + msg + self.ender)
        else:
            self.client.chat_postMessage(
                channel=channel,
                text=msg)

    def upload_file(self, title, filename, channel=None):
        if channel is None:
            channel = self.channel
        file = open(filename, 'rb')
        self.client.files_upload(channels=channel, filename=filename, file=file, title=title)
        file.close()




import setuptools

with open("README.md", 'r') as fh:
    long_description = fh.read()

setuptools.setup(
    name='daniels',
    description='Daniel, the autoreporter.',
    long_description_content_type='text/markdown',
    long_description=long_description,
    url="https://github.com/harvested-financial/daniels",
    version='0.1.7',
    author='Rory Gwozdz',
    author_email='rory@harvestedfinancial.com',
    liscense='MIT',
    packages=setuptools.find_packages(),
    install_requires=['slackclient'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"],
    keywords=['pip', 'slack', 'daniel'],
    python_requires='>=3.6',
)
